@@ -206,8 +206,11 @@ class Heat(OpenStackBase):
         return ansible.get_hostvars(variable=None)
 
     def get_stack_definition(self, host):
-        hostvars = self.get_stack_definitions()[host]
-        return Heat.hostvars_to_stack(host, hostvars)
+        hostvars = self.get_stack_definitions().get(host)
+        if hostvars:
+            return Heat.hostvars_to_stack(host, hostvars)
+        else:
+            return None
 
     @staticmethod
     def hostvars_to_stack(host, hv):
@@ -277,8 +280,9 @@ class Heat(OpenStackBase):
 
     def create_test_subdomain(self, domain):
         d = f"{self.config_dir}/inventory/group_vars/all"
-        assert os.path.exists(d)
+        assert os.path.exists(d), d
         if 'bind-host' not in Stack(self.config_dir, **self.args).list():
+            log.info('bind-host does not exist, doing nothing')
             return None
         h = Heat(self.config_dir, **self.args)
         s = Stack(self.config_dir, h.get_stack_definition('bind-host'),
