@@ -8,8 +8,7 @@ IcingaHelper.icinga_host = 'bind-host'
 class TestChecks(IcingaHelper):
 
     def test_host(self):
-        r = self.get_client().objects.get('Host', 'postfix-host')
-        assert r['attrs']['name'] == 'postfix-host'
+        assert 'postfix-host' in self.get_hosts(host='postfix-host')
 
     def test_service(self, host):
         #  r = self.get_client().objects.list('Service', joins=['host.name'])
